﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using GenericParsing;
using SoftArtisans.OfficeWriter.WordWriter;

namespace SalesInvoice
{
    public partial class Part2 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void RunReport_Click(object sender, EventArgs e)
        {
            try
            {
                BindTemplateData();
            }
            catch (Exception ex)
            {
                ErrorLabel.Visible = true;
                //If OfficeWriter isn't installed, show this error message
                if (ex.Message.Contains("General license key exception"))
                {
                    ErrorLabel.Text = "OfficeWriter does not appear to be" +
                       " installed on this machine. If you have not " +
                       "purchased OfficeWriter, you can download the " +
                       "evaluation version here: " +
                       "http://www.officewriter.com/officewriter-free-evaluation.aspx";
                }
                else
                {
                    ErrorLabel.Text = ex.Message;
                }
            }
        }

        private void BindTemplateData()
        {
            //Instantiate a new WordTemplate object
            WordTemplate WT = new WordTemplate();

            //Open the template file
            WT.Open(Page.MapPath("//templates//Part2_Invoice_Template.docx"));

            //Create the array of header values
            object[] orderHeader = { "Jane", "Doe", DateTime.Now.ToString("MM/dd/yy"), 13139.51, 558.43, 13697.94 };
            //Create the array of column names
            string[] orderHeaderColNames = { "FirstName", "LastName", "Date", "Subtotal", "Tax", "Total" };

            //Get the order info datatable using GenericParser
            DataTable dtOrderInfo = GetCSVData("//data//OrderInfo.csv");

            //Set the repeat block to bind the data for multiple order items
            WT.SetRepeatBlock(dtOrderInfo, "Repeat");
            //Set the header data source to import a single row of data
            WT.SetDataSource(orderHeader, orderHeaderColNames, "OrderHeader");

            //Process to import the data to the template
            WT.Process();

            WT.Save(Response, "Part2_Output.docx", false);

        }

        #region Utility Methods
        /// <summary>
        /// Helper method that uses CSVParser
        /// </summary>
        /// <param name="filename">Filename of CSV</param>
        /// <returns>Populated DataTable</returns>
        protected DataTable GetCSVData(string filename)
        {
            DataTable dt = new DataTable();
            using (GenericParserAdapter parser = new GenericParserAdapter(Page.MapPath(filename)))
            {
                parser.ColumnDelimiter = ',';
                parser.FirstRowHasHeader = true;

                dt = parser.GetDataTable();
            }
            return dt;
        }

        #endregion
    }
}
